==> haskell-hspec-core-2.4.4-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.4.4
id: hspec-core-2.4.4-FTBFvC7qw2S4F0s3HJygaa
key: hspec-core-2.4.4-FTBFvC7qw2S4F0s3HJygaa
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters.Diff Test.Hspec.Core.Formatters.Free
                Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Options
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner.Eval
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Data.Algorithm.Diff Paths_hspec_core
abi: d6e76d4d88f1f8f258296beb940926e4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-core-2.4.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-core-2.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hspec-core-2.4.4
hs-libraries: HShspec-core-2.4.4-FTBFvC7qw2S4F0s3HJygaa
depends:
    base-4.10.0.0 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx
    setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU time-1.8.0.2
    transformers-0.5.2.0 deepseq-1.4.3.0
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
    quickcheck-io-0.2.0-DGgxP10rQS5DEjc4UQAWme
    hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
    call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86 directory-1.3.0.2
    filepath-1.4.1.2 array-0.5.2.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx=69aa16d23e0434a9386def58aa582c19
             setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29=221ec96ab272bbe35b12c27562404c0e
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
             quickcheck-io-0.2.0-DGgxP10rQS5DEjc4UQAWme=f6c81d408ca49d2e8eaa47afa6aa3c6e
             hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt=09cca836cd3c3bccf406f2b40e0a2223
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86=074cd9d4520ab1fa3869b4e9283eb803
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             array-0.5.2.0=044554210403f250e868a2183de060a9
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.4.4-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.4.4
id: hspec-core-2.4.4-HCSTC9t7mbfETD97riQOBD
key: hspec-core-2.4.4-HCSTC9t7mbfETD97riQOBD
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters.Diff Test.Hspec.Core.Formatters.Free
                Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Options
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner.Eval
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Data.Algorithm.Diff Paths_hspec_core
abi: 6299ed9f5d5847e2c1b2076084e66ac3
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-core-2.4.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-core-2.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hspec-core-2.4.4
hs-libraries: HShspec-core-2.4.4-HCSTC9t7mbfETD97riQOBD
depends:
    base-4.10.0.0 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx
    setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU time-1.8.0.2
    transformers-0.5.2.0 deepseq-1.4.3.0
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    quickcheck-io-0.2.0-1Jyoobgydpi1ixfo6rI3UE
    hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
    call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86 directory-1.3.0.2
    filepath-1.4.1.2 array-0.5.2.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx=69aa16d23e0434a9386def58aa582c19
             setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29=221ec96ab272bbe35b12c27562404c0e
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             quickcheck-io-0.2.0-1Jyoobgydpi1ixfo6rI3UE=4904961eab8930a57829bb3ce1105d35
             hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt=09cca836cd3c3bccf406f2b40e0a2223
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86=074cd9d4520ab1fa3869b4e9283eb803
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             array-0.5.2.0=044554210403f250e868a2183de060a9
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
